@@ -16,8 +16,10 @@
 import time
 import uuid
 
+from cliff import columns as cliff_columns
 import mock
 
+from osc_lib.cli import format_columns
 from osc_lib import exceptions
 from osc_lib.tests import fakes
 from osc_lib.tests import utils as test_utils
@@ -628,3 +630,59 @@ class TestFindResource(test_utils.TestCase):
         actual_unsorted = utils.format_list(['c', 'b', 'a'], separator='\n')
         self.assertEqual(expected, actual_pre_sorted)
         self.assertEqual(expected, actual_unsorted)
+
+
+class TestAssertItemEqual(test_utils.TestCommand):
+
+    def test_assert_normal_item(self):
+        expected = ['a', 'b', 'c']
+        actual = ['a', 'b', 'c']
+        self.assertItemEqual(expected, actual)
+
+    def test_assert_item_with_formattable_columns(self):
+        expected = [format_columns.DictColumn({'a': 1, 'b': 2}),
+                    format_columns.ListColumn(['x', 'y', 'z'])]
+        actual = [format_columns.DictColumn({'a': 1, 'b': 2}),
+                  format_columns.ListColumn(['x', 'y', 'z'])]
+        self.assertItemEqual(expected, actual)
+
+    def test_assert_item_different_length(self):
+        expected = ['a', 'b', 'c']
+        actual = ['a', 'b']
+        self.assertRaises(AssertionError,
+                          self.assertItemEqual, expected, actual)
+
+    def test_assert_item_formattable_columns_vs_legacy_formatter(self):
+        expected = [format_columns.DictColumn({'a': 1, 'b': 2}),
+                    format_columns.ListColumn(['x', 'y', 'z'])]
+        actual = [utils.format_dict({'a': 1, 'b': 2}),
+                  utils.format_list(['x', 'y', 'z'])]
+        self.assertRaises(AssertionError,
+                          self.assertItemEqual, expected, actual)
+
+    def test_assert_item_different_formattable_columns(self):
+
+        class ExceptionColumn(cliff_columns.FormattableColumn):
+            def human_readable(self):
+                raise Exception('always fail')
+
+        expected = [format_columns.DictColumn({'a': 1, 'b': 2})]
+        actual = [ExceptionColumn({'a': 1, 'b': 2})]
+        # AssertionError is a subclass of Exception
+        # so raising AssertionError ensures ExceptionColumn.human_readable()
+        # is not called.
+        self.assertRaises(AssertionError,
+                          self.assertItemEqual, expected, actual)
+
+    def test_assert_list_item(self):
+        expected = [
+            ['a', 'b', 'c'],
+            [format_columns.DictColumn({'a': 1, 'b': 2}),
+             format_columns.ListColumn(['x', 'y', 'z'])]
+        ]
+        actual = [
+            ['a', 'b', 'c'],
+            [format_columns.DictColumn({'a': 1, 'b': 2}),
+             format_columns.ListColumn(['x', 'y', 'z'])]
+        ]
+        self.assertListItemEqual(expected, actual)
